@@ -11,4 +11,6 @@ enableSemantics();
 {{ extension.getLocalSettingsLine(mwShortVersion) }}{% endfor %}
 # modified defaults
 # https://www.mediawiki.org/wiki/Manual:$wgEnableUploads
-$wgEnableUploads = true;
\ No newline at end of file
+$wgEnableUploads = true;
+# https://github.com/WolfgangFahl/pymediawikidocker/issues/30:
+$wgDeprecationReleaseLimit = "1.35.0";
\ No newline at end of file
